This is the fork of pef which is used for uninstalling libraries and its dependancies from https://github.com/cls1991/pef

I have just removed restriction of having virtual environment so it can also uninstall system level packages.

Warning : Use it at your own responsibility.

Note : I am in the process of creating python package for it.
Any contributions and suggestions are welcome.
